<?php
if ( ! defined( 'ABSPATH' ) ) {
exit;
}
/*
Plugin Name: Bluchic Gallery
Description: A gallery creation and listing for WordPress, works with <a href="http://www.bluchic.com/?utm_source=plugin&utm_medium=instagram-plugin&utm_campaign=plugin-redirection" target="_blank">Bluchic themes</a>. Use <strong>[bluchic-gallery]</strong> or  <strong>[bluchic-gallery tag="family"]</strong> shortcode on page or post.
Version: 21.09
License: GPL
Author: Bluchic
Author URI: http://www.bluchic.com
Plugin URI: http://www.bluchic.com
*/

/*  Copyright 2011  Bluchic  (email : hello@bluchic.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// ==================================================================
// Add script and style on header
// ==================================================================
function bluchic_gallery_styles_scripts(){
	wp_enqueue_style( 'bluchic_gallery_style', plugins_url( 'bluchic_gallery_style.css', __FILE__ ), '', '' );
	wp_enqueue_script( 'bluchic_gallery_shuffle_script', plugins_url( '/js/jquery.shuffle.min.js', __FILE__ ), array( 'jquery' ), null, true );
}
add_action( 'wp_enqueue_scripts', 'bluchic_gallery_styles_scripts' );

// ==================================================================
// Load textdomain
// ==================================================================
function bluchic_gallery_textdomain() {
	load_plugin_textdomain( 'bluchic-gallery', false, basename( dirname( __FILE__ ) ) . '/languages' ); 
}
add_action( 'plugins_loaded', 'bluchic_gallery_textdomain' );

// ==================================================================
// Shortcodes
// ==================================================================
function bluchic_gallery_shortcode( $atts, $content = null ) {
	$atts = shortcode_atts([
		'tag' => ''
	], $atts, 'bluchic-gallery' );

	ob_start();
	include ( 'bluchic_gallery_query.php' );
	$output = ob_get_clean();
	return $output;
}

add_shortcode( 'bluchic-gallery', 'bluchic_gallery_shortcode' );

// ==================================================================
// Register Custom Post Type - Gallery
// ==================================================================
function bluchic_gallery_type() {

	$labels = array(
		'name'                  => _x( 'Gallery', 'Post Type General Name', 'ace' ),
		'singular_name'         => _x( 'Gallery', 'Post Type Singular Name', 'ace' ),
		'menu_name'             => __( 'Gallery', 'ace' ),
		'name_admin_bar'        => __( 'Gallery', 'ace' ),
		'archives'              => __( 'Gallery Archives', 'ace' ),
		'parent_item_colon'     => __( 'Parent Item:', 'ace' ),
		'all_items'             => __( 'All Gallery', 'ace' ),
		'add_new_item'          => __( 'Add New Gallery', 'ace' ),
		'add_new'               => __( 'Add Gallery', 'ace' ),
		'new_item'              => __( 'New Gallery', 'ace' ),
		'edit_item'             => __( 'Edit Gallery', 'ace' ),
		'update_item'           => __( 'Update Gallery', 'ace' ),
		'view_item'             => __( 'View Gallery', 'ace' ),
		'search_items'          => __( 'Search Gallery', 'ace' ),
		'not_found'             => __( 'Not found', 'ace' ),
		'not_found_in_trash'    => __( 'Not found in Trash', 'ace' ),
		'featured_image'        => __( 'Gallery Cover', 'ace' ),
		'set_featured_image'    => __( 'Set Gallery Album Cover', 'ace' ),
		'remove_featured_image' => __( 'Remove Gallery Album Cover', 'ace' ),
		'use_featured_image'    => __( 'Use as Gallery Album Cover', 'ace' ),
		'insert_into_item'      => __( 'Insert into item', 'ace' ),
		'uploaded_to_this_item' => __( 'Uploaded to this item', 'ace' ),
		'items_list'            => __( 'Items list', 'ace' ),
		'items_list_navigation' => __( 'Items list navigation', 'ace' ),
		'filter_items_list'     => __( 'Filter items list', 'ace' ),
	);

	$args = array(
		'label'                 => __( 'Gallery', 'ace' ),
		'labels'                => $labels,
		'supports'              => array( 'title', 'editor', 'thumbnail', ),
		'hierarchical'          => false,
		'public'                => true,
		'show_ui'               => true,
		'show_in_menu'          => true,
		'taxonomies'            => array( 'gallery-tags' ),
		'menu_position'         => 5,
		'menu_icon'             => 'dashicons-format-gallery',
		'show_in_admin_bar'     => true,
		'show_in_nav_menus'     => true,
		'can_export'            => true,
		'exclude_from_search'   => false,
		'publicly_queryable'    => true,
		'capability_type'       => 'post',
	);
	register_post_type( 'gallery', $args );

}
add_action( 'init', 'bluchic_gallery_type', 0 );

// ==================================================================
// Custom Post Taxonomy
// ==================================================================
function bluchic_gallery_tags_taxononmy() {

    $labels = array(
        'name'                       => 'Gallery Tag',
        'singular_name'              => 'Gallery Tag',
        'menu_name'                  => 'Gallery Tags',
        'all_items'                  => 'All Gallery Tags',
        'parent_item'                => 'Parent Gallery Tag',
        'parent_item_colon'          => 'Parent Gallery Tag:',
        'new_item_name'              => 'New Gallery Tag',
        'add_new_item'               => 'Add New Gallery Tag',
        'edit_item'                  => 'Edit Gallery Tag',
        'update_item'                => 'Update Gallery Tag',
        'separate_items_with_commas' => '<strong>Use only one Gallery Tag</strong>',
        'search_items'               => 'Search Gallery Tags',
        'add_or_remove_items'        => 'Add or remove Gallery Tags',
        'choose_from_most_used'      => 'Choose from the most used Gallery Tags',
        'not_found'                  => 'Not Found',
    );
    $args = array(
        'labels'			=> $labels,
		'hierarchical'		=> false,
        'public'			=> true,
        'show_ui'			=> true,
        'show_admin_column'	=> true,
        'show_in_nav_menus'	=> true,
        'show_tagcloud'		=> true,
    );
    register_taxonomy( 'gallery-tags', array( 'gallery' ), $args );

}
add_action( 'init', 'bluchic_gallery_tags_taxononmy', 0 );

// ==================================================================
// Custom Post Type Template
// ==================================================================
function bluchic_gallery_type_template( $single ) {
	global $wp_query, $post;
	/* Checks for single template by post type */
	if( $post->post_type == "gallery" ) {
    	if( file_exists( get_template_directory(). '/layouts/full-page.php' ) ) {
        	return get_template_directory() . '/layouts/full-page.php';
        } elseif( file_exists( get_template_directory(). '/layouts/page_full.php' ) ) {
        	return get_template_directory() . '/layouts/page_full.php';
        }
	}
    return $single;
}
add_filter('single_template', 'bluchic_gallery_type_template');
