<?php
if (! defined('ABSPATH')) {
exit;
}
/*
Plugin Name: Bluchic Portfolio
Description: A portfolio creation and listing for WordPress, works with <a href="http://www.bluchic.com/?utm_source=plugin&utm_medium=bluchic-plugin&utm_campaign=plugin-redirection" target="_blank">Bluchic themes</a>. Use <strong>[bluchic-portfolio]</strong> shortcode on page or post.
Version: 21.09
License: GPL
Author: Bluchic
Author URI: http://www.bluchic.com
Plugin URI: http://www.bluchic.com
*/

/*  Copyright 2011  Bluchic  (email : hello@bluchic.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 2, as 
	published by the Free Software Foundation.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// ==================================================================
// Add script and style on header
// ==================================================================
function bluchic_portfolio_styles_scripts(){
	wp_enqueue_style('bluchic_portfolio_style', plugins_url('bluchic_portfolio_style.css', __FILE__), '', '');
	wp_enqueue_script('bluchic_portfolio_shuffle_script', plugins_url('/js/jquery.shuffle.min.js', __FILE__), array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'bluchic_portfolio_styles_scripts');

// ==================================================================
// Load textdomain
// ==================================================================
function bluchic_portfolio_textdomain() {
	load_plugin_textdomain('bluchic-portfolio', false, basename(dirname(__FILE__)) . '/languages'); 
}
add_action('plugins_loaded', 'bluchic_portfolio_textdomain');

// ==================================================================
// Shortcodes
// ==================================================================
function bluchic_portfolio_shortcode($atts, $content = null) {
	$atts = extract(shortcode_atts(array(
		'orderby' => 'date',
		'posts_per_page' => '30'
	), $atts, 'bluchic-portfolio'));

	ob_start();
	include ('bluchic_portfolio_query.php');
	$output = ob_get_clean();
	return $output;
}

add_shortcode('bluchic-portfolio', 'bluchic_portfolio_shortcode');

// ==================================================================
// Register Custom Post Type - Portfolio
// ==================================================================
function bluchic_portfolio_type() {

	$labels = array(
		'name'                  => _x('Portfolio', 'Post Type General Name', 'ace'),
		'singular_name'         => _x('Portfolio', 'Post Type Singular Name', 'ace'),
		'menu_name'             => __('Portfolio', 'ace'),
		'name_admin_bar'        => __('Portfolio', 'ace'),
		'archives'              => __('Portfolio Archives', 'ace'),
		'parent_item_colon'     => __('Parent Item:', 'ace'),
		'all_items'             => __('All Portfolio', 'ace'),
		'add_new_item'          => __('Add New Portfolio', 'ace'),
		'add_new'               => __('Add Portfolio', 'ace'),
		'new_item'              => __('New Portfolio', 'ace'),
		'edit_item'             => __('Edit Portfolio', 'ace'),
		'update_item'           => __('Update Portfolio', 'ace'),
		'view_item'             => __('View Portfolio', 'ace'),
		'search_items'          => __('Search Portfolio', 'ace'),
		'not_found'             => __('Not found', 'ace'),
		'not_found_in_trash'    => __('Not found in Trash', 'ace'),
		'featured_image'        => __('Portfolio Cover', 'ace'),
		'set_featured_image'    => __('Set Portfolio Cover', 'ace'),
		'remove_featured_image' => __('Remove Portfolio Cover', 'ace'),
		'use_featured_image'    => __('Use as Portfolio Cover', 'ace'),
		'insert_into_item'      => __('Insert into item', 'ace'),
		'uploaded_to_this_item' => __('Uploaded to this item', 'ace'),
		'items_list'            => __('Items list', 'ace'),
		'items_list_navigation' => __('Items list navigation', 'ace'),
		'filter_items_list'     => __('Filter items list', 'ace'),
		);

	$args = array(
		'label'                 => __('Portfolio', 'ace'),
		'labels'                => $labels,
		'supports'              => array('title', 'editor', 'thumbnail',),
		'hierarchical'          => false,
		'public'                => true,
		'show_ui'               => true,
		'show_in_menu'          => true,
		'show_in_rest'          => true,
		'taxonomies'            => array('portfolio-tags'),
		'menu_position'         => 5,
		'menu_icon'             => 'dashicons-portfolio',
		'show_in_admin_bar'     => true,
		'show_in_nav_menus'     => true,
		'can_export'            => true,
		'exclude_from_search'   => false,
		'publicly_queryable'    => true,
		'capability_type'       => 'post',
		);
	register_post_type('portfolio', $args);

}
add_action('init', 'bluchic_portfolio_type', 0);

// ==================================================================
// Custom Post Taxonomy
// ==================================================================
function bluchic_portfolio_tags_taxononmy() {

    $labels = array(
        'name'                       => 'Portfolio Tag',
        'singular_name'              => 'Portfolio Tag',
        'menu_name'                  => 'Portfolio Tags',
        'all_items'                  => 'All Portfolio Tags',
        'parent_item'                => 'Parent Portfolio Tag',
        'parent_item_colon'          => 'Parent Portfolio Tag:',
        'new_item_name'              => 'New Portfolio Tag',
        'add_new_item'               => 'Add New Portfolio Tag',
        'edit_item'                  => 'Edit Portfolio Tag',
        'update_item'                => 'Update Portfolio Tag',
        'separate_items_with_commas' => '<strong>Use only one Portfolio Tag</strong>',
        'search_items'               => 'Search Portfolio Tags',
        'add_or_remove_items'        => 'Add or remove Portfolio Tags',
        'choose_from_most_used'      => 'Choose from the most used Portfolio Tags',
        'not_found'                  => 'Not Found',
   	);
    $args = array(
        'labels'			=> $labels,
		'hierarchical'		=> false,
        'public'			=> true,
        'show_ui'			=> true,
        'show_admin_column'	=> true,
        'show_in_nav_menus'	=> true,
        'show_tagcloud'		=> true,
		'show_in_rest'      => true,
   	);
    register_taxonomy('portfolio-tags', array('portfolio'), $args);

}
add_action('init', 'bluchic_portfolio_tags_taxononmy', 0);

// ==================================================================
// Custom Post Type Template
// ==================================================================
function bluchic_portfolio_type_template($single) {
	global $wp_query, $post;
	/* Checks for single template by post type */
	if($post->post_type == "portfolio") {
    	if(file_exists(get_template_directory(). '/layouts/full-page.php'))
        	return get_template_directory() . '/layouts/full-page.php';
	}
    return $single;
}
add_filter('single_template', 'bluchic_portfolio_type_template');
