<?php
if ( ! defined( 'ABSPATH' ) ) {
exit;
}
/*
Plugin Name: Bluchic Testimonial
Description: This plugin comes with a custom post type to create your testimonials; a shortcode and widget for you to easily show a slide of testimonials. Use <strong>[bc-testimonial speed="500" timeout="5000"]</strong> shortcode on page/post/custom HTML widget.
Version: 21.09
License: GPL
Author: Bluchic
Author URI: http://www.bluchic.com
Plugin URI: http://www.bluchic.com
*/

/*  Copyright 2011  Bluchic  (email : hello@bluchic.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

define( 'bc_testimonial_dir', plugin_dir_path(__FILE__) );
define( 'bc_testimonial_url', plugin_dir_url(__FILE__) );

// ==================================================================
// Load textdomain
// ==================================================================
function bc_testimonial_load_textdomain() {
	load_plugin_textdomain( 'bc-testimonial', false, basename( dirname( __FILE__ ) ) . '/languages' );
}
add_action( 'plugins_loaded', 'bc_testimonial_load_textdomain' );

// ==================================================================
// Add script and style on header
// ==================================================================
function bc_testimonial_styles_scripts(){
  wp_enqueue_script( 'jquery' );
  wp_enqueue_style( 'bc_testimonial_style', plugins_url( 'bc-testimonial-responsiveslides.css', __FILE__ ), '', '' );
  wp_enqueue_script( 'bc_testimonial_flexslider', plugins_url( 'bc-testimonial-responsiveslides.min.js', __FILE__ ), '', '1.54', true );
}
add_action( 'wp_footer', 'bc_testimonial_styles_scripts' );

// ==================================================================
// Post type - Press
// ==================================================================
function bluchic_post_type_testimonial() {
register_post_type( 'bc_testimonial',
  array(
  'label'               => __( 'Testimonial', 'bc-testimonial' ),
  'singular'            => __( 'Testimonial', 'bc-testimonial' ),
  'description'         => __( 'Testimonial content', 'bc-testimonial' ),
  'public'              => true,
  'capability_type'     => 'page',
  'exclude_from_search' => true,
  'hierarchical'        => true,
  'query_var'           => true,
  'show_in_rest'        => true,
  'menu_icon'           => 'dashicons-format-quote',
  'menu_position'       => 5,
  'supports'            => array(
    'title',
    'editor',
    'thumbnail',
    'page-attributes',
  ),
  'rewrite'             => true,
  ));
}

add_action( 'init', 'bluchic_post_type_testimonial' );

// ==================================================================
// Press query shortcode
// ==================================================================
function bc_testimonial_list( $atts ) {
	extract( shortcode_atts( array(
		'speed'     => '500',
		'timeout'   => '5000'
	), $atts ) );

	ob_start();
    include ( 'bc-testimonial-loop.php' );
    $output = ob_get_clean();
    return $output;

}
add_shortcode( 'bc-testimonial', 'bc_testimonial_list' );



// ==================================================================
// Press widget
// ==================================================================
class bc_testimonial_widget extends WP_Widget {

  function __construct() {
    $widget_ops = array( 'description' => __( 'Show Testimonial slider', 'bc-testimonial' ) );
    WP_Widget::__construct( false, __( 'Bluchic Testimonial Widget', 'bc-testimonial' ), $widget_ops );
  }

  function widget( $args, $data ) {
  extract( $args );
    $title  = isset( $data[ 'title' ] ) ? esc_attr( $data[ 'title' ] ) : '';

    echo $before_widget; ?>

      <?php if( $title ) { echo $before_title . $title . $after_title; } ?>

		<?php include ( 'bc-testimonial-loop-widget.php' ); ?>

    <?php echo $after_widget; }
    function update( $new_data, $old_data ) { return $new_data; }
    function form( $data ) {
      $title  = isset( $data[ 'title' ] ) ? esc_attr( $data[ 'title' ] ) : '';
    ?>

<p>
  <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title', 'bc-testimonial' ); ?>:</label>
  <input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>"  value="<?php echo $title; ?>" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" />
</p>

  <?php }

}

function bc_testimonial_widget() {
  register_widget( 'bc_testimonial_widget' );
}
add_action( 'widgets_init','bc_testimonial_widget');
